<?php $TRANSLATIONS = array(
"No file provided for import" => "没有文件被选择导入",
"Unsupported file type for import" => "不支持导入的文件类型",
"Bookmarks" => "书签",
"Tags" => "标签",
"Filter by tag" => "按标签过滤",
"Edit bookmark" => "编辑书签",
"Are you sure you want to remove this tag from every entry?" => "您确定要从所有条目中移除此标签吗？",
"Warning" => "警告",
"Import error" => "导入出错",
"Import completed successfully." => "导入完全成功。",
"Uploading..." => "上传中...",
"Bookm." => "订阅它们。",
"Add a bookmark" => "添加书签",
"Close" => "关闭",
"The title of the page" => "页面标题",
"The address of the page" => "页面地址",
"Description of the page" => "页面描述",
"Save" => "保存",
"Delete" => "删除",
"Edit" => "编辑",
"Cancel" => "取消",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "拖动此物到您的浏览器书签栏，在您想要快速订阅某网页时点击：",
"Read later" => "稍后阅读",
"Address" => "网址",
"Add" => "添加",
"Related Tags" => "相关标签",
"Settings" => "设置",
"You have no bookmarks" => "您没有书签",
"You can also try to import a bookmark file" => "您也可以尝试导入一个书签文件",
"Bookmarklet" => "书签",
"Export & Import" => "导出 & 导入",
"Export" => "导出",
"Import" => "导入"
);
